@@ -324,6 +324,14 @@ class LoadMaster(HttpClient):
                 rs = virt_serv.build_real_server(server_data)
                 virt_serv.real_servers.append(rs)
             virtual_services.append(virt_serv)
+        # replace subvs's with vs's that have RSs in them.
+        for vs in virtual_services:
+            vs.subvs_entries = []
+            parent_vs_id = vs.mastervsid
+            if parent_vs_id != 0:
+                for parent_vs in virtual_services:
+                    if parent_vs.index == parent_vs_id:
+                        parent_vs.subvs_entries.append(vs)
 
         return virtual_services
 
@@ -633,7 +641,7 @@ class KempBaseObjectModel(object):
     _API_IGNORE = (
         "ip_address", "endpoint", "rsindex", "vsindex", "index", "status",
         "subvs_data", "subvs_entries", "real_servers", "cert", "rsminimum",
-        "checkuse1_1"
+        "checkuse1_1", "mastervsid"
     )
 
     def __repr__(self):
@@ -833,6 +841,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.extraports = service.get('ExtraPorts', None)
         self.qos = service.get('QoS', None)
         self.idletime = service.get('Idletime', None)
+        self.mastervsid = service.get('MasterVSID', None)
 
         # Real servers section
         self.checktype = service.get('CheckType', None)
